@@ -16,13 +16,17 @@ class ValidatedPathOperation(Enum):
 
     ADD_FILES = "add_files"
     MAKE_DIRS = "make_dirs"
+    ADD_SYMLINKS = "add_symlinks"
 
+    def allowed_dirs(self):
+        """Return the list of allowed top-level directories for this operation."""
+        if self == ValidatedPathOperation.ADD_FILES:
+            return ["/etc/", "/usr/"]
+        elif self == ValidatedPathOperation.MAKE_DIRS:
+            return ["/etc/", "/usr/", "/var/"]
+        elif self == ValidatedPathOperation.ADD_SYMLINKS:
+            return ["/etc/", "/usr/", "/var/"]
 
-# Allowed top-level directories per operation type
-ALLOWED_DIRS_BY_OPERATION = {
-    ValidatedPathOperation.ADD_FILES: ["/etc/", "/usr/"],
-    ValidatedPathOperation.MAKE_DIRS: ["/etc/", "/usr/", "/var/"],
-}
 
 # Disallowed paths (take precedence over allowed directories)
 DISALLOWED_PATHS = [
@@ -158,7 +162,9 @@ class ExtraInclude:
             matched_files = self._find_glob_matches(source_glob)
         except exceptions.NoMatchingFilesError:
             if allow_empty:
-                contents.make_dirs.append({"path": dest_dir, "parents": True})
+                contents.make_dirs.append(
+                    {"path": dest_dir, "parents": True, "exist_ok": True}
+                )
                 log.info(
                     "Glob pattern '%s' matched no files, but allow_empty=True, "
                     "so creating destination directory '%s'",
@@ -285,7 +291,10 @@ class ExtraInclude:
 
         if parent_dir not in existing_dirs:
             # Add directory to make_dirs if it's not already there
-            contents.make_dirs.append({"path": parent_dir, "parents": True})
+            # Use exist_ok to avoid failures when directory already exists
+            contents.make_dirs.append(
+                {"path": parent_dir, "parents": True, "exist_ok": True}
+            )
 
     def _add_file_to_content(self, contents, file_data):
         """Add a file to the content processing pipeline"""
@@ -335,6 +344,7 @@ class Contents:
         self.chmod_files = data.get("chmod_files", [])
         self.remove_files = data.get("remove_files", [])
         self.make_dirs = data.get("make_dirs", [])
+        self.add_symlinks = data.get("add_symlinks", [])
         self.file_content_copy = []
         self.systemd = data.get("systemd", {})
         self.sbom = data.get("sbom", {})
@@ -344,31 +354,32 @@ class Contents:
     def _validate_path(self, path, operation_type):
         """Check if a single path is under allowed top-level directories."""
         # Get the allowed directories for this operation type
-        allowed_dirs = ALLOWED_DIRS_BY_OPERATION[operation_type]
+        allowed_dirs = operation_type.allowed_dirs()
 
         # First check if path is explicitly disallowed
         if any(path.startswith(prefix) for prefix in DISALLOWED_PATHS):
             raise exceptions.InvalidTopLevelPath(
-                path, allowed_dirs, operation_type.value
+                path, allowed_dirs, DISALLOWED_PATHS, operation_type.value
             )
 
         # Then check if path is under allowed directories
         if not any(path.startswith(prefix) for prefix in allowed_dirs):
             raise exceptions.InvalidTopLevelPath(
-                path, allowed_dirs, operation_type.value
+                path, allowed_dirs, DISALLOWED_PATHS, operation_type.value
             )
 
     def validate_paths(self):
         """Validate that all paths are under allowed top-level directories."""
-        # Validate make_dirs
-        for dir_entry in self.make_dirs:
-            self._validate_path(dir_entry.get("path"), ValidatedPathOperation.MAKE_DIRS)
+        # List of (data, path_key, operation_type) tuples to validate
+        validations = [
+            (self.make_dirs, "path", ValidatedPathOperation.MAKE_DIRS),
+            (self.add_files, "path", ValidatedPathOperation.ADD_FILES),
+            (self.add_symlinks, "link", ValidatedPathOperation.ADD_SYMLINKS),
+        ]
 
-        # Validate add_files destination paths
-        for file_entry in self.add_files:
-            self._validate_path(
-                file_entry.get("path", ""), ValidatedPathOperation.ADD_FILES
-            )
+        for data, path_key, operation_type in validations:
+            for entry in data:
+                self._validate_path(entry.get(path_key, ""), operation_type)
 
     # Gets key to use for target partition (rootfs/qm)
     def get_key(self, key):
@@ -386,6 +397,16 @@ class Contents:
 
         self.set_define("simple_mkdir", self.make_dirs)
 
+        simple_symlinks = [
+            {
+                "target": s["target"],
+                "link_name": "tree://" + s["link"],
+                "symbolic": True,
+            }
+            for s in self.add_symlinks
+        ]
+        self.set_define("simple_symlinks", simple_symlinks)
+
         chmod_files = {f["path"]: without(f, "path") for f in self.chmod_files}
         self.set_define("simple_chmod", chmod_files)
 
