@@ -1,6 +1,7 @@
 import pytest
 
-from aib.main import parse_args
+import aib.main  # noqa: F401
+from aib.arguments import parse_args
 
 
 @pytest.mark.parametrize("arg_before_subcommand", [True, False])
@@ -11,14 +12,14 @@ from aib.main import parse_args
             "build",
             "--container",
             [],
-            ["--export", "qcow2", "test.mpp.yml", "output"],
+            ["--target", "qemu", "test.mpp.yml", "output"],
             True,
         ),
         (
             "build",
             "--include",
             ["/some/path"],
-            ["--export", "qcow2", "test.mpp.yml", "output.json"],
+            ["--target", "qemu", "test.mpp.yml", "output.json"],
             "/some/path",
         ),
         ("list-distro", "--include", ["/some/path"], [], "/some/path"),
@@ -33,10 +34,10 @@ def test_args_work_before_and_after_subcommands(
     else:
         args = [subcommand] + [arg_name] + arg_value + extra_args
 
-    parsed = parse_args(args, "")
+    parsed = parse_args(args)
 
     # Derive attribute name from argument name
-    attr_name = arg_name.lstrip("--").replace("-", "_")
+    attr_name = arg_name.removeprefix("--").replace("-", "_")
     attr_value = getattr(parsed, attr_name)
 
     # Check the argument was parsed correctly
