@@ -1,12 +1,12 @@
 import pytest
 from unittest.mock import MagicMock, patch
 
+import aib.main  # noqa: F401
 from aib import AIBParameters
 from aib import exceptions
-from aib.main import parse_args
+from aib.arguments import parse_args
 from aib.runner import Runner
 
-
 BASE_DIR = "/usr/lib/automotive-image-builder"
 
 
@@ -44,9 +44,13 @@ def test_run_args_root(
     subprocess_mock.run = subprocess_run
     args = args_for(use_container, use_user_container)
     runner = Runner(
-        AIBParameters(parse_args(args, base_dir=BASE_DIR), base_dir=BASE_DIR)
+        AIBParameters(
+            parse_args(args),
+            base_dir=BASE_DIR,
+        )
     )
     runner.use_sudo_for_root = use_sudo_for_root
+    runner.ensure_sudo = MagicMock()
 
     cmd = ["touch", "example"]
     runner.run_as_root(cmd)
@@ -76,9 +80,13 @@ def test_run_args_container_without_progress_no_capture(
 
     args = args_for(use_container, use_user_container)
     runner = Runner(
-        AIBParameters(parse_args(args, base_dir=BASE_DIR), base_dir=BASE_DIR)
+        AIBParameters(
+            parse_args(args),
+            base_dir=BASE_DIR,
+        )
     )
     runner.use_sudo_for_root = use_sudo_for_root
+    runner.ensure_sudo = MagicMock()
 
     cmd = ["touch", "example"]
     runner.run_in_container(cmd, progress=False, capture_output=False, verbose=verbose)
@@ -118,9 +126,13 @@ def test_run_args_container_without_progress_with_capture(
 
     args = args_for(use_container, use_user_container)
     runner = Runner(
-        AIBParameters(parse_args(args, base_dir=BASE_DIR), base_dir=BASE_DIR)
+        AIBParameters(
+            parse_args(args),
+            base_dir=BASE_DIR,
+        )
     )
     runner.use_sudo_for_root = use_sudo_for_root
+    runner.ensure_sudo = MagicMock()
 
     cmd = ["touch", "example"]
     runner.run_in_container(cmd, progress=False, capture_output=True, verbose=verbose)
@@ -172,9 +184,13 @@ def test_run_args_container_with_progress(
 
     args = args_for(use_container, use_user_container)
     runner = Runner(
-        AIBParameters(parse_args(args, base_dir=BASE_DIR), base_dir=BASE_DIR)
+        AIBParameters(
+            parse_args(args),
+            base_dir=BASE_DIR,
+        )
     )
     runner.use_sudo_for_root = use_sudo_for_root
+    runner.ensure_sudo = MagicMock()
 
     cmd = ["touch", "example"]
     runner.run_in_container(
@@ -220,9 +236,13 @@ def test_run_args_osbuild_without_progress_no_capture(
 
     args = args_for(use_container, use_user_container)
     runner = Runner(
-        AIBParameters(parse_args(args, base_dir=BASE_DIR), base_dir=BASE_DIR)
+        AIBParameters(
+            parse_args(args),
+            base_dir=BASE_DIR,
+        )
     )
     runner.use_sudo_for_root = use_sudo_for_root
+    runner.ensure_sudo = MagicMock()
 
     cmd = ["touch", "example"]
     runner.run_in_container(
@@ -268,9 +288,13 @@ def test_run_args_osbuild_without_progress_with_capture(
 
     args = args_for(use_container, use_user_container)
     runner = Runner(
-        AIBParameters(parse_args(args, base_dir=BASE_DIR), base_dir=BASE_DIR)
+        AIBParameters(
+            parse_args(args),
+            base_dir=BASE_DIR,
+        )
     )
     runner.use_sudo_for_root = use_sudo_for_root
+    runner.ensure_sudo = MagicMock()
 
     cmd = ["touch", "example"]
     runner.run_in_container(
@@ -328,9 +352,13 @@ def test_run_args_osbuild_with_progress(
 
     args = args_for(use_container, use_user_container)
     runner = Runner(
-        AIBParameters(parse_args(args, base_dir=BASE_DIR), base_dir=BASE_DIR)
+        AIBParameters(
+            parse_args(args),
+            base_dir=BASE_DIR,
+        )
     )
     runner.use_sudo_for_root = use_sudo_for_root
+    runner.ensure_sudo = MagicMock()
 
     cmd = ["touch", "example"]
     runner.run_in_container(
@@ -377,10 +405,9 @@ def test_run_with_log_file(
     log_file_path = str(tmp_path / "test.log")
 
     args = args_for(False, False)
-    runner = Runner(
-        AIBParameters(parse_args(args, base_dir=BASE_DIR), base_dir=BASE_DIR)
-    )
+    runner = Runner(AIBParameters(parse_args(args), base_dir=BASE_DIR))
     runner.use_sudo_for_root = use_sudo_for_root
+    runner.ensure_sudo = MagicMock()
 
     cmd = ["touch", "example"]
     runner.run_in_container(
@@ -411,9 +438,13 @@ def test_run_args_user(
     subprocess_mock.run = subprocess_run
     args = args_for(use_container, use_user_container)
     runner = Runner(
-        AIBParameters(parse_args(args, base_dir=BASE_DIR), base_dir=BASE_DIR)
+        AIBParameters(
+            parse_args(args),
+            base_dir=BASE_DIR,
+        )
     )
     runner.use_sudo_for_root = use_sudo_for_root
+    runner.ensure_sudo = MagicMock()
 
     cmd = ["touch", "example"]
     runner.run_as_user(cmd)
@@ -452,11 +483,14 @@ def test_collect_podman_args(container_autoupdate, use_non_root, volumes):
     if container_autoupdate:
         args += ["--container-autoupdate"]
     runner = Runner(
-        AIBParameters(parse_args(args, base_dir=BASE_DIR), base_dir=BASE_DIR)
+        AIBParameters(
+            parse_args(args),
+            base_dir=BASE_DIR,
+        )
     )
     for v in volumes:
         runner.add_volume(v)
-    podman_args = runner._collect_podman_args(False, use_non_root, False)
+    podman_args = runner._collect_podman_args(False, use_non_root, False, False)
 
     index = 3
     assert podman_args[:2] == ["--rm", "--workdir"]
@@ -484,11 +518,64 @@ def test_collect_podman_args(container_autoupdate, use_non_root, volumes):
 def test_run_in_container_progress_without_log_file_raises_exception(use_container):
     args = ["--container"] if use_container else []
     runner = Runner(
-        AIBParameters(parse_args(args, base_dir=BASE_DIR), base_dir=BASE_DIR)
+        AIBParameters(
+            parse_args(args),
+            base_dir=BASE_DIR,
+        )
     )
+    runner.ensure_sudo = MagicMock()
 
     cmd = ["osbuild", "manifest.json"]
 
     # Should raise MissingLogFile when progress=True but log_file=None
     with pytest.raises(exceptions.MissingLogFile):
         runner.run_in_container(cmd, progress=True, log_file=None)
+
+
+@patch("aib.runner.threading.Thread")
+@patch("aib.runner.subprocess")
+def test_ensure_sudo_success(subprocess_mock, thread_mock):
+    """Test that ensure_sudo calls sudo -v and starts keepalive thread."""
+    # Setup
+    args = MagicMock()
+    args.container = False
+    args.user_container = False
+    args.include_dirs = []
+
+    runner = Runner(args)
+    runner.use_sudo_for_root = True
+
+    # Execution
+    runner.ensure_sudo()
+
+    # Verification
+    subprocess_mock.check_call.assert_called_once_with(["sudo", "-v"])
+
+    thread_mock.assert_called_once()
+    call_args = thread_mock.call_args
+    assert call_args.kwargs["daemon"] is True
+
+    thread_instance = thread_mock.return_value
+    thread_instance.start.assert_called_once()
+
+
+def test_ensure_sudo_already_running():
+    """Test that ensure_sudo does nothing if keepalive thread is alive."""
+    args = MagicMock()
+    args.container = False
+    args.user_container = False
+    args.include_dirs = []
+
+    runner = Runner(args)
+    runner.use_sudo_for_root = True
+
+    # Mock existing thread
+    mock_thread = MagicMock()
+    mock_thread.is_alive.return_value = True
+    runner.keepalive_thread = mock_thread
+
+    # We shouldn't need to mock subprocess because it shouldn't be called
+    # But to be safe and catch regressions, we can patch it
+    with patch("aib.runner.subprocess") as subprocess_mock:
+        runner.ensure_sudo()
+        subprocess_mock.check_call.assert_not_called()
