@@ -2,12 +2,20 @@
 
 source "$(dirname ${BASH_SOURCE[0]})"/../../scripts/test-lib.sh
 
-echo_log "Starting build for container_images and qm.content.container_images test..."
-build --export bootc-tar --extend-define tar_paths="['usr/share/containers/storage/overlay-images', 'usr/lib/qm/rootfs/usr/share/containers/storage/overlay-images']" container-image.aib.yml out.tar
-echo_log "Build completed, output: out.tar"
+TAR_FILE="out.tar"
 
-echo_log "Extracting out.tar..."
-tar xvf out.tar > /dev/null
+# Update cleanup function parameters on each test artifact change
+trap 'cleanup_path "$TAR_FILE" "usr"' 'EXIT'
+
+echo_log "Starting build for container_images and qm.content.container_images test..."
+build --tar \
+    --extend-define tar_paths="['usr/share/containers/storage/overlay-images', 'usr/lib/qm/rootfs/usr/share/containers/storage/overlay-images']" \
+    container-image.aib.yml \
+    "$TAR_FILE"
+echo_log "Build completed, output: $TAR_FILE"
+
+echo_log "Extracting $TAR_FILE..."
+tar xvf "$TAR_FILE" > /dev/null
 
 BASE_IMAGE_JSON="./usr/share/containers/storage/overlay-images/images.json"
 QM_IMAGE_JSON="./usr/lib/qm/rootfs/usr/share/containers/storage/overlay-images/images.json"
