@@ -2,12 +2,19 @@
 
 source "$(dirname ${BASH_SOURCE[0]})"/../../scripts/test-lib.sh
 
-echo_log "Starting build..."
-build --export bootc-tar systemd-services.aib.yml out.tar
-echo_log "Build completed, output: out.tar"
+TAR_FILE="out.tar"
 
-echo_log "Extracting out.tar..."
-tar xvf out.tar > /dev/null
+# Update cleanup function parameters on each test artifact change
+trap 'cleanup_path "$TAR_FILE" "etc" "usr" "error.txt" "error2.txt"' 'EXIT'
+
+echo_log "Starting build..."
+build --tar \
+    systemd-services.aib.yml \
+    "$TAR_FILE"
+echo_log "Build completed, output: $TAR_FILE"
+
+echo_log "Extracting $TAR_FILE..."
+tar xvf "$TAR_FILE" > /dev/null
 
 echo_log "Checking symlinks for content section"
 assert_service_enabled sshd.service content
